@@ -1,5 +1,5 @@
-import keras
-import keras.backend as K
+from keras_bert.backend import keras
+from keras_bert.backend import backend as K
 
 
 class Masked(keras.layers.Layer):
@@ -18,9 +18,9 @@ class Masked(keras.layers.Layer):
         :param return_masked: Whether to return the merged mask.
         :param kwargs: Arguments for parent class.
         """
+        super(Masked, self).__init__(**kwargs)
         self.supports_masking = True
         self.return_masked = return_masked
-        super(Masked, self).__init__(**kwargs)
 
     def get_config(self):
         config = {
@@ -36,9 +36,13 @@ class Masked(keras.layers.Layer):
 
     def compute_mask(self, inputs, mask=None):
         token_mask = K.not_equal(inputs[1], 0)
-        return K.all(K.stack([token_mask, mask[0]], axis=0), axis=0)
+        masked = K.all(K.stack([token_mask, mask[0]], axis=0), axis=0)
+        if self.return_masked:
+            return [masked, None]
+        return masked
 
     def call(self, inputs, mask=None, **kwargs):
+        output = inputs[0] + 0
         if self.return_masked:
-            return [inputs[0], K.cast(self.compute_mask(inputs, mask), K.floatx())]
-        return inputs[0]
+            return [output, K.cast(self.compute_mask(inputs, mask)[0], K.floatx())]
+        return output
